/*
  Copyright 2009 Patrick Ahlbrecht

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
*/

import javax.xml.parsers.*;
import java.io.*;

/**
 * Core of the application
 */
public class Table2GridBag {
  
  public Table2GridBag() {}
  
  /**
   * Process one HTML file
   * @param f the file to translate
   * @throws anything that the SAXParser might throw
   */
  public void process(File f) throws Exception {
    String indent = "\t";  // Indent character
    String lname = "gbl";  // Name of the GridBagLayout object in the source
    String cname = "gbc";  // Name of the GridBagConstraints object
    String container = null;  // Produce code to layout another object
    
    if (System.getProperty("container")!=null) container=System.getProperty("container");
    if (System.getProperty("indent")!=null) container=System.getProperty("indent");
    if (System.getProperty("lname")!=null) container=System.getProperty("lname");
    if (System.getProperty("cname")!=null) container=System.getProperty("cname");
    
    TableParser tp = new TableParser();
    SAXParserFactory.newInstance().newSAXParser().parse(f,tp);
    System.out.println(Cell.generate(tp.getCells(),indent,lname,cname,container));
  }
  
  /**
   * Print Usage info
   */
  public static void printUsage() {
    System.err.println("Table2GridBag - (C) 2009 Patrick Ahlbrecht");
    System.err.println("Produce GridBagLayout code from HTML tables");
    System.err.println("Usage: java -jar Table2GridBag layout.html > snippet.java");
    System.err.println("For further details, see: http://www.onyxbits.de/");
  }
  
  /**
   * Start program
   * @param args Each entry is one HTML file
   * @throws Anything that makes it to the main method
   */
  public static void main(String args[]) throws Exception {
    if (args==null || args.length==0) {
      printUsage();
      System.exit(1);
    }
    for(String arg:args) new Table2GridBag().process(new File(arg));
  }
}